@@ -30,7 +30,7 @@ from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 class DruidHook(BaseHook):
     """
-    Connection to Druid overlord for ingestion
+    Connection to Druid overlord for ingestion.
 
     To connect to a Druid cluster that is secured with the druid-basic-security
     extension, add the username and password to the druid ingestion connection.
@@ -45,7 +45,7 @@ class DruidHook(BaseHook):
 
     def __init__(
         self,
-        druid_ingest_conn_id: str = 'druid_ingest_default',
+        druid_ingest_conn_id: str = "druid_ingest_default",
         timeout: int = 1,
         max_ingestion_time: int | None = None,
     ) -> None:
@@ -54,18 +54,18 @@ class DruidHook(BaseHook):
         self.druid_ingest_conn_id = druid_ingest_conn_id
         self.timeout = timeout
         self.max_ingestion_time = max_ingestion_time
-        self.header = {'content-type': 'application/json'}
+        self.header = {"content-type": "application/json"}
 
         if self.timeout < 1:
             raise ValueError("Druid timeout should be equal or greater than 1")
 
     def get_conn_url(self) -> str:
-        """Get Druid connection url"""
+        """Get Druid connection url."""
         conn = self.get_connection(self.druid_ingest_conn_id)
         host = conn.host
         port = conn.port
-        conn_type = conn.conn_type or 'http'
-        endpoint = conn.extra_dejson.get('endpoint', '')
+        conn_type = conn.conn_type or "http"
+        endpoint = conn.extra_dejson.get("endpoint", "")
         return f"{conn_type}://{host}:{port}/{endpoint}"
 
     def get_auth(self) -> requests.auth.HTTPBasicAuth | None:
@@ -83,17 +83,20 @@ class DruidHook(BaseHook):
             return None
 
     def submit_indexing_job(self, json_index_spec: dict[str, Any] | str) -> None:
-        """Submit Druid ingestion job"""
+        """Submit Druid ingestion job."""
         url = self.get_conn_url()
 
         self.log.info("Druid ingestion spec: %s", json_index_spec)
         req_index = requests.post(url, data=json_index_spec, headers=self.header, auth=self.get_auth())
-        if req_index.status_code != 200:
-            raise AirflowException(f'Did not get 200 when submitting the Druid job to {url}')
+
+        code = req_index.status_code
+        if code != 200:
+            self.log.error("Error submitting the Druid job to %s (%s) %s", url, code, req_index.content)
+            raise AirflowException(f"Did not get 200 when submitting the Druid job to {url}")
 
         req_json = req_index.json()
         # Wait until the job is completed
-        druid_task_id = req_json['task']
+        druid_task_id = req_json["task"]
         self.log.info("Druid indexing task-id: %s", druid_task_id)
 
         running = True
@@ -107,37 +110,37 @@ class DruidHook(BaseHook):
             if self.max_ingestion_time and sec > self.max_ingestion_time:
                 # ensure that the job gets killed if the max ingestion time is exceeded
                 requests.post(f"{url}/{druid_task_id}/shutdown", auth=self.get_auth())
-                raise AirflowException(f'Druid ingestion took more than {self.max_ingestion_time} seconds')
+                raise AirflowException(f"Druid ingestion took more than {self.max_ingestion_time} seconds")
 
             time.sleep(self.timeout)
 
             sec += self.timeout
 
-            status = req_status.json()['status']['status']
-            if status == 'RUNNING':
+            status = req_status.json()["status"]["status"]
+            if status == "RUNNING":
                 running = True
-            elif status == 'SUCCESS':
+            elif status == "SUCCESS":
                 running = False  # Great success!
-            elif status == 'FAILED':
-                raise AirflowException('Druid indexing job failed, check console for more info')
+            elif status == "FAILED":
+                raise AirflowException("Druid indexing job failed, check console for more info")
             else:
-                raise AirflowException(f'Could not get status of the job, got {status}')
+                raise AirflowException(f"Could not get status of the job, got {status}")
 
-        self.log.info('Successful index')
+        self.log.info("Successful index")
 
 
 class DruidDbApiHook(DbApiHook):
     """
-    Interact with Druid broker
+    Interact with Druid broker.
 
     This hook is purely for users to query druid broker.
     For ingestion, please use druidHook.
     """
 
-    conn_name_attr = 'druid_broker_conn_id'
-    default_conn_name = 'druid_broker_default'
-    conn_type = 'druid'
-    hook_name = 'Druid'
+    conn_name_attr = "druid_broker_conn_id"
+    default_conn_name = "druid_broker_default"
+    conn_type = "druid"
+    hook_name = "Druid"
     supports_autocommit = False
 
     def get_conn(self) -> connect:
@@ -146,12 +149,12 @@ class DruidDbApiHook(DbApiHook):
         druid_broker_conn = connect(
             host=conn.host,
             port=conn.port,
-            path=conn.extra_dejson.get('endpoint', '/druid/v2/sql'),
-            scheme=conn.extra_dejson.get('schema', 'http'),
+            path=conn.extra_dejson.get("endpoint", "/druid/v2/sql"),
+            scheme=conn.extra_dejson.get("schema", "http"),
             user=conn.login,
             password=conn.password,
         )
-        self.log.info('Get the connection to druid broker on %s using user %s', conn.host, conn.login)
+        self.log.info("Get the connection to druid broker on %s using user %s", conn.host, conn.login)
         return druid_broker_conn
 
     def get_uri(self) -> str:
@@ -163,10 +166,10 @@ class DruidDbApiHook(DbApiHook):
         conn = self.get_connection(getattr(self, self.conn_name_attr))
         host = conn.host
         if conn.port is not None:
-            host += f':{conn.port}'
-        conn_type = conn.conn_type or 'druid'
-        endpoint = conn.extra_dejson.get('endpoint', 'druid/v2/sql')
-        return f'{conn_type}://{host}/{endpoint}'
+            host += f":{conn.port}"
+        conn_type = conn.conn_type or "druid"
+        endpoint = conn.extra_dejson.get("endpoint", "druid/v2/sql")
+        return f"{conn_type}://{host}/{endpoint}"
 
     def set_autocommit(self, conn: connect, autocommit: bool) -> NotImplementedError:
         raise NotImplementedError()
